@@ -300,7 +300,7 @@ module test;
   assign _saxi_bready = 1;
   assign _saxi_arcache = 3;
   assign _saxi_arprot = 0;
-  reg [32-1:0] outstanding_wreq_count_9;
+  reg [3-1:0] outstanding_wcount_9;
   wire [32-1:0] _tmp_10;
   assign _tmp_10 = _saxi_awaddr;
 
@@ -467,7 +467,7 @@ module test;
     _saxi_wvalid = 0;
     _saxi_araddr = 0;
     _saxi_arvalid = 0;
-    outstanding_wreq_count_9 = 0;
+    outstanding_wcount_9 = 0;
     counter = 0;
     th_ctrl = th_ctrl_init;
     _th_ctrl_i_12 = 0;
@@ -755,7 +755,7 @@ module test;
 
   always @(posedge uut_CLK) begin
     if(uut_RST) begin
-      outstanding_wreq_count_9 <= 0;
+      outstanding_wcount_9 <= 0;
       _saxi_awaddr <= 0;
       _saxi_awvalid <= 0;
       __saxi_cond_0_1 <= 0;
@@ -804,11 +804,11 @@ module test;
       if(__saxi_cond_9_1) begin
         _saxi_arvalid <= 0;
       end 
-      if(_saxi_awvalid && _saxi_awready && !(_saxi_bvalid && _saxi_bready)) begin
-        outstanding_wreq_count_9 <= outstanding_wreq_count_9 + 1;
+      if(_saxi_wvalid && _saxi_wready && !(_saxi_bvalid && _saxi_bready) && (outstanding_wcount_9 < 7)) begin
+        outstanding_wcount_9 <= outstanding_wcount_9 + 1;
       end 
-      if(!(_saxi_awvalid && _saxi_awready) && (_saxi_bvalid && _saxi_bready) && (outstanding_wreq_count_9 > 0)) begin
-        outstanding_wreq_count_9 <= outstanding_wreq_count_9 - 1;
+      if(!(_saxi_wvalid && _saxi_wready) && (_saxi_bvalid && _saxi_bready) && (outstanding_wcount_9 > 0)) begin
+        outstanding_wcount_9 <= outstanding_wcount_9 - 1;
       end 
       if((th_ctrl == 6) && (_saxi_awready || !_saxi_awvalid)) begin
         _saxi_awaddr <= _th_ctrl_awaddr_13;
@@ -818,7 +818,7 @@ module test;
       if(_saxi_awvalid && !_saxi_awready) begin
         _saxi_awvalid <= _saxi_awvalid;
       end 
-      if((th_ctrl == 7) && (_saxi_wready || !_saxi_wvalid)) begin
+      if((th_ctrl == 7) && ((outstanding_wcount_9 < 6) && (_saxi_wready || !_saxi_wvalid))) begin
         _saxi_wdata <= 4096;
         _saxi_wvalid <= 1;
         _saxi_wstrb <= { 4{ 1'd1 } };
@@ -835,7 +835,7 @@ module test;
       if(_saxi_awvalid && !_saxi_awready) begin
         _saxi_awvalid <= _saxi_awvalid;
       end 
-      if((th_ctrl == 12) && (_saxi_wready || !_saxi_wvalid)) begin
+      if((th_ctrl == 12) && ((outstanding_wcount_9 < 6) && (_saxi_wready || !_saxi_wvalid))) begin
         _saxi_wdata <= _th_ctrl_src_offset_14;
         _saxi_wvalid <= 1;
         _saxi_wstrb <= { 4{ 1'd1 } };
@@ -852,7 +852,7 @@ module test;
       if(_saxi_awvalid && !_saxi_awready) begin
         _saxi_awvalid <= _saxi_awvalid;
       end 
-      if((th_ctrl == 17) && (_saxi_wready || !_saxi_wvalid)) begin
+      if((th_ctrl == 17) && ((outstanding_wcount_9 < 6) && (_saxi_wready || !_saxi_wvalid))) begin
         _saxi_wdata <= _th_ctrl_dst_offset_15;
         _saxi_wvalid <= 1;
         _saxi_wstrb <= { 4{ 1'd1 } };
@@ -869,7 +869,7 @@ module test;
       if(_saxi_awvalid && !_saxi_awready) begin
         _saxi_awvalid <= _saxi_awvalid;
       end 
-      if((th_ctrl == 22) && (_saxi_wready || !_saxi_wvalid)) begin
+      if((th_ctrl == 22) && ((outstanding_wcount_9 < 6) && (_saxi_wready || !_saxi_wvalid))) begin
         _saxi_wdata <= 1;
         _saxi_wvalid <= 1;
         _saxi_wstrb <= { 4{ 1'd1 } };
@@ -991,7 +991,7 @@ module test;
           end 
         end
         th_ctrl_7: begin
-          if(_saxi_wready || !_saxi_wvalid) begin
+          if((outstanding_wcount_9 < 6) && (_saxi_wready || !_saxi_wvalid)) begin
             th_ctrl <= th_ctrl_8;
           end 
         end
@@ -1013,7 +1013,7 @@ module test;
           end 
         end
         th_ctrl_12: begin
-          if(_saxi_wready || !_saxi_wvalid) begin
+          if((outstanding_wcount_9 < 6) && (_saxi_wready || !_saxi_wvalid)) begin
             th_ctrl <= th_ctrl_13;
           end 
         end
@@ -1035,7 +1035,7 @@ module test;
           end 
         end
         th_ctrl_17: begin
-          if(_saxi_wready || !_saxi_wvalid) begin
+          if((outstanding_wcount_9 < 6) && (_saxi_wready || !_saxi_wvalid)) begin
             th_ctrl <= th_ctrl_18;
           end 
         end
@@ -1057,7 +1057,7 @@ module test;
           end 
         end
         th_ctrl_22: begin
-          if(_saxi_wready || !_saxi_wvalid) begin
+          if((outstanding_wcount_9 < 6) && (_saxi_wready || !_saxi_wvalid)) begin
             th_ctrl <= th_ctrl_23;
           end 
         end
@@ -1239,7 +1239,7 @@ module blinkled
   assign maxi_arprot = 0;
   assign maxi_arqos = 0;
   assign maxi_aruser = 0;
-  reg [32-1:0] outstanding_wreq_count_0;
+  reg [3-1:0] outstanding_wcount_0;
   reg _maxi_read_start;
   reg [8-1:0] _maxi_read_op_sel;
   reg [32-1:0] _maxi_read_local_addr;
@@ -1441,7 +1441,7 @@ module blinkled
   wire [32-1:0] _dataflow__variable_odata_1;
   wire _dataflow__variable_ovalid_1;
   wire _dataflow__variable_oready_1;
-  assign _dataflow__variable_oready_1 = (_maxi_write_fsm == 3) && (_maxi_write_op_sel == 1) && ((counter_32 > 0) && (maxi_wready || !maxi_wvalid));
+  assign _dataflow__variable_oready_1 = (_maxi_write_fsm == 3) && (_maxi_write_op_sel == 1) && ((counter_32 > 0) && (outstanding_wcount_0 < 6) && (maxi_wready || !maxi_wvalid));
   reg _maxi_cond_2_1;
   assign _maxi_write_data_done = (last_33 && maxi_wvalid && maxi_wready)? 1 : 0;
   reg axim_flag_34;
@@ -1521,7 +1521,7 @@ module blinkled
 
   always @(posedge CLK) begin
     if(RST) begin
-      outstanding_wreq_count_0 <= 0;
+      outstanding_wcount_0 <= 0;
       _maxi_read_start <= 0;
       _maxi_write_start <= 0;
       _maxi_ram_a_0_read_start <= 0;
@@ -1576,11 +1576,11 @@ module blinkled
         maxi_wlast <= 0;
         last_33 <= 0;
       end 
-      if(maxi_awvalid && maxi_awready && !(maxi_bvalid && maxi_bready)) begin
-        outstanding_wreq_count_0 <= outstanding_wreq_count_0 + 1;
+      if(maxi_wlast && maxi_wvalid && maxi_wready && !(maxi_bvalid && maxi_bready) && (outstanding_wcount_0 < 7)) begin
+        outstanding_wcount_0 <= outstanding_wcount_0 + 1;
       end 
-      if(!(maxi_awvalid && maxi_awready) && (maxi_bvalid && maxi_bready) && (outstanding_wreq_count_0 > 0)) begin
-        outstanding_wreq_count_0 <= outstanding_wreq_count_0 - 1;
+      if(!(maxi_wlast && maxi_wvalid && maxi_wready) && (maxi_bvalid && maxi_bready) && (outstanding_wcount_0 > 0)) begin
+        outstanding_wcount_0 <= outstanding_wcount_0 - 1;
       end 
       _maxi_read_start <= 0;
       _maxi_write_start <= 0;
@@ -1653,14 +1653,14 @@ module blinkled
       if(maxi_awvalid && !maxi_awready) begin
         maxi_awvalid <= maxi_awvalid;
       end 
-      if(_dataflow__variable_ovalid_1 && ((_maxi_write_fsm == 3) && (_maxi_write_op_sel == 1) && ((counter_32 > 0) && (maxi_wready || !maxi_wvalid))) && ((counter_32 > 0) && (maxi_wready || !maxi_wvalid) && (counter_32 > 0))) begin
+      if(_dataflow__variable_ovalid_1 && ((_maxi_write_fsm == 3) && (_maxi_write_op_sel == 1) && ((counter_32 > 0) && (outstanding_wcount_0 < 6) && (maxi_wready || !maxi_wvalid))) && ((counter_32 > 0) && (outstanding_wcount_0 < 6) && (maxi_wready || !maxi_wvalid) && (counter_32 > 0))) begin
         maxi_wdata <= _dataflow__variable_odata_1;
         maxi_wvalid <= 1;
         maxi_wlast <= 0;
         maxi_wstrb <= { 4{ 1'd1 } };
         counter_32 <= counter_32 - 1;
       end 
-      if(_dataflow__variable_ovalid_1 && ((_maxi_write_fsm == 3) && (_maxi_write_op_sel == 1) && ((counter_32 > 0) && (maxi_wready || !maxi_wvalid))) && ((counter_32 > 0) && (maxi_wready || !maxi_wvalid) && (counter_32 > 0)) && (counter_32 == 1)) begin
+      if(_dataflow__variable_ovalid_1 && ((_maxi_write_fsm == 3) && (_maxi_write_op_sel == 1) && ((counter_32 > 0) && (outstanding_wcount_0 < 6) && (maxi_wready || !maxi_wvalid))) && ((counter_32 > 0) && (outstanding_wcount_0 < 6) && (maxi_wready || !maxi_wvalid) && (counter_32 > 0)) && (counter_32 == 1)) begin
         maxi_wlast <= 1;
         last_33 <= 1;
       end 
@@ -2110,7 +2110,7 @@ module blinkled
           th_memcpy <= th_memcpy_29;
         end
         th_memcpy_29: begin
-          if(_maxi_write_idle && (outstanding_wreq_count_0 == 0)) begin
+          if(_maxi_write_idle && (outstanding_wcount_0 == 0)) begin
             th_memcpy <= th_memcpy_30;
           end 
         end
