@@ -27,12 +27,6 @@ module test #
   );
 
 
-  initial begin
-    $dumpfile("uut.vcd");
-    $dumpvars(0, uut);
-  end
-
-
   initial begin
     CLK = 0;
     forever begin
