@@ -56,7 +56,7 @@ module test;
   assign _axi_bready = 1;
   assign _axi_arcache = 3;
   assign _axi_arprot = 0;
-  reg [32-1:0] outstanding_wreq_count_0;
+  reg [3-1:0] outstanding_wcount_0;
   assign _axi_rready = 0;
   wire [32-1:0] _tmp_1;
   assign _tmp_1 = _axi_awaddr;
@@ -212,7 +212,7 @@ module test;
     _axi_wvalid = 0;
     _axi_araddr = 0;
     _axi_arvalid = 0;
-    outstanding_wreq_count_0 = 0;
+    outstanding_wcount_0 = 0;
     fsm = fsm_init;
     __axi_cond_0_1 = 0;
     wdata = 0;
@@ -230,7 +230,7 @@ module test;
 
   always @(posedge CLK) begin
     if(RST) begin
-      outstanding_wreq_count_0 <= 0;
+      outstanding_wcount_0 <= 0;
       _axi_araddr <= 0;
       _axi_arvalid <= 0;
       _axi_awaddr <= 0;
@@ -255,11 +255,11 @@ module test;
       if(__axi_cond_3_1) begin
         _axi_wvalid <= 0;
       end 
-      if(_axi_awvalid && _axi_awready && !(_axi_bvalid && _axi_bready)) begin
-        outstanding_wreq_count_0 <= outstanding_wreq_count_0 + 1;
+      if(_axi_wvalid && _axi_wready && !(_axi_bvalid && _axi_bready) && (outstanding_wcount_0 < 7)) begin
+        outstanding_wcount_0 <= outstanding_wcount_0 + 1;
       end 
-      if(!(_axi_awvalid && _axi_awready) && (_axi_bvalid && _axi_bready) && (outstanding_wreq_count_0 > 0)) begin
-        outstanding_wreq_count_0 <= outstanding_wreq_count_0 - 1;
+      if(!(_axi_wvalid && _axi_wready) && (_axi_bvalid && _axi_bready) && (outstanding_wcount_0 > 0)) begin
+        outstanding_wcount_0 <= outstanding_wcount_0 - 1;
       end 
       _axi_araddr <= 0;
       _axi_arvalid <= 0;
@@ -271,7 +271,7 @@ module test;
       if(_axi_awvalid && !_axi_awready) begin
         _axi_awvalid <= _axi_awvalid;
       end 
-      if((fsm == 101) && (_axi_wready || !_axi_wvalid)) begin
+      if((fsm == 101) && ((outstanding_wcount_0 < 6) && (_axi_wready || !_axi_wvalid))) begin
         _axi_wdata <= wdata;
         _axi_wvalid <= 1;
         _axi_wstrb <= { 4{ 1'd1 } };
@@ -288,7 +288,7 @@ module test;
       if(_axi_awvalid && !_axi_awready) begin
         _axi_awvalid <= _axi_awvalid;
       end 
-      if((fsm == 103) && (_axi_wready || !_axi_wvalid)) begin
+      if((fsm == 103) && ((outstanding_wcount_0 < 6) && (_axi_wready || !_axi_wvalid))) begin
         _axi_wdata <= wdata;
         _axi_wvalid <= 1;
         _axi_wstrb <= { 4{ 1'd1 } };
@@ -725,7 +725,7 @@ module test;
           end 
         end
         fsm_101: begin
-          if(_axi_wready || !_axi_wvalid) begin
+          if((outstanding_wcount_0 < 6) && (_axi_wready || !_axi_wvalid)) begin
             fsm <= fsm_102;
           end 
         end
@@ -738,7 +738,7 @@ module test;
           end 
         end
         fsm_103: begin
-          if(_axi_wready || !_axi_wvalid) begin
+          if((outstanding_wcount_0 < 6) && (_axi_wready || !_axi_wvalid)) begin
             fsm <= fsm_104;
           end 
         end
