@@ -17,12 +17,6 @@ module test;
   );
 
 
-  initial begin
-    $dumpfile("uut.vcd");
-    $dumpvars(0, uut, uut_CLK, uut_RST);
-  end
-
-
   initial begin
     uut_CLK = 0;
     forever begin
@@ -81,6 +75,7 @@ module blinkled #
 endmodule
 """
 
+
 def test():
     veriloggen.reset()
     test_module = types_fixed_add.mkTest()
