@@ -28,11 +28,42 @@ def _tmp_name(prefix='_tmp_thread'):
     return ret
 
 
+class CompileError(Exception):
+
+    def __init__(self, err, code, lineno, col_offset,
+                 end_lineno=None, end_col_offset=None):
+        self.err = err
+        self.code = code
+        self.lineno = lineno
+        self.col_offset = col_offset
+        self.end_lineno = end_lineno
+        self.end_col_offset = end_col_offset
+
+    def __str__(self):
+        return '"{}" in "{}", line {}'.format(self.err, self.code, self.lineno)
+
+
 class FunctionVisitor(ast.NodeVisitor):
 
     def __init__(self):
         self.functions = OrderedDict()
 
+    def visit(self, node):
+        try:
+            r = ast.NodeVisitor.visit(self, node)
+            return r
+
+        except CompileError as e:
+            raise
+
+        except Exception as e:
+            if hasattr(ast, 'unparse'):
+                code = ast.unparse(node)
+            else:
+                code = ast.dump(node)
+            raise CompileError(e, code, node.lineno, node.col_offset,
+                               node.end_lineno, node.end_col_offset)
+
     def getFunctions(self):
         return self.functions
 
@@ -68,6 +99,23 @@ class CompileVisitor(ast.NodeVisitor):
         for func in functions.values():
             self.scope.addFunction(func)
 
+    # -------------------------------------------------------------------------
+    def visit(self, node):
+        try:
+            r = ast.NodeVisitor.visit(self, node)
+            return r
+
+        except CompileError as e:
+            raise
+
+        except Exception as e:
+            if hasattr(ast, 'unparse'):
+                code = ast.unparse(node)
+            else:
+                code = ast.dump(node)
+            raise CompileError(e, code, node.lineno, node.col_offset,
+                               node.end_lineno, node.end_col_offset)
+
     # -------------------------------------------------------------------------
     def visit_Import(self, node):
         raise TypeError("{} is not supported.".format(type(node)))
@@ -80,7 +128,7 @@ class CompileVisitor(ast.NodeVisitor):
 
     # -------------------------------------------------------------------------
     def visit_FunctionDef(self, node):
-        self.scope.addFunction(node)
+        raise NotImplementedError('closure is not supported.')
 
     def visit_Assign(self, node):
         if self.skip():
@@ -705,12 +753,10 @@ class CompileVisitor(ast.NodeVisitor):
 
     # ------------------------------------------------------------------
     def visit_Nonlocal(self, node):
-        for name in node.names:
-            self.addNonlocal(name)
+        raise NotImplementedError('nonlocal is not supported.')
 
     def visit_Global(self, node):
-        for name in node.names:
-            self.addGlobal(name)
+        raise NotImplementedError('global is not supported.')
 
     def visit_Pass(self, node):
         pass
@@ -1085,12 +1131,6 @@ class CompileVisitor(ast.NodeVisitor):
             return global_objects[name]
         return None
 
-    def addNonlocal(self, name):
-        self.scope.addNonlocal(name)
-
-    def addGlobal(self, name):
-        self.scope.addGlobal(name)
-
     def getFunction(self, name):
         func = self.scope.searchFunction(name)
         if func is not None:
